aboutsummaryrefslogtreecommitdiff
path: root/src/kernel/paging/paging.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/kernel/paging/paging.h')
-rw-r--r--src/kernel/paging/paging.h12
1 files changed, 11 insertions, 1 deletions
diff --git a/src/kernel/paging/paging.h b/src/kernel/paging/paging.h
index 51f407f..681b84e 100644
--- a/src/kernel/paging/paging.h
+++ b/src/kernel/paging/paging.h
@@ -25,11 +25,21 @@ typedef struct page_directory {
} page_directory_t;
/**
* Initialize the environment and enables paging
*/
void initialise_paging();
/**
+ * Enable paging bit in CR0 (without initializing)
+ */
+void enable_paging();
+
+/**
+ * Disable paging bit in CR0
+ */
+void disable_paging();
+
+/**
* Load the page directory into the CR3 register
* @param new The page directory
*/
@@ -25,11 +25,21 @@ typedef struct page_directory {
} page_directory_t;
/**
- * Initialize the environment and enables paging
+ * Initialize the environment and enable paging
*/
void initialise_paging();